<template>
    <checkout-layout :cart_data="cart_data">
        <template #credit_check v-if="cart_data!=null && cart_data.cart_details.length>0">
            <credit-check></credit-check>
        </template>
        <template #checkout_form v-if="cart_data!=null">
            <checkout-form-2 :cart_data="cart_data"></checkout-form-2>
        </template>
    </checkout-layout>
</template>
<script>
import {cloneDeep} from 'lodash';
var moment=require('moment');
export default {
    components : {CheckoutLayout:()=>import('~/layouts/cart/checkout-2.vue'), CreditCheck : ()=>import('~/components/front-end/cart-component/credit-check.vue'), SuggestedProduct:()=>import('~/components/front-end/cart-component/suggested-product.vue'),CheckoutForm2 : ()=>import('~/components/front-end/cart-component/checkout-form-2.vue')},
    data() {
        return {
            loading     : false,
            cart_data : cloneDeep(this.$store.state.front_end_data.cart_data),
            insert_code : false,
            domain      : this.$store.state.front_end_data.domain,
        }
    },
    head() {
        return {
            title: `Checkout 2 - ${this.domain.name}`,
            script : [
              {
                src: '/front-end/js/google-analytics.js'
              }
            ],
            meta: [
                {
                  hid: 'description',
                  name: 'description',
                  content: "Cart"
                },
                {
                  hid: 'og:title',
                  name: 'og:title',
                  content: "Cart"
                },
                {
                  hid: 'og:description',
                  name: 'og:description',
                  content: "Cart"
                },{
                  hid: 'og:type',
                  name: 'og:type',
                  content: "Website"
                },
                {
                  hid: 'og:url',
                  name: 'og:url',
                  content: this.domain.url + this.$route.fullPath
                },
                {
                  hid: 'og:url',
                  name: 'og:site_name',
                  content: this.domain.name
                },
                {
                  hid: 'og:image',
                  name: 'og:image',
                  content: "/images/logo.png"
                },
                {
                  hid: 'name',
                  name: 'twitter:card',
                  content: "summary_large_image"
                },
                {
                  hid: 'name',
                  name: 'twitter:title',
                  content: "Cart"
                },
                {
                  hid: 'name',
                  name: 'twitter:description',
                  content: "Cart"
                },
                {
                  hid: 'name',
                  name: 'twitter:image:src',
                  content: "/images/logo.png"
                },
                {
                  hid: 'name',
                  name: 'twitter:site',
                  content: this.domain.name
                },
              ],
          }
    },
    mounted() {
        if(this.cart_data.preferred_contact_time==null || this.cart_data.preferred_contact_time=='') {
            this.cart_data.preferred_contact_time="Anytime";
        }
        this.initial_data  = JSON.stringify(cloneDeep(this.cart_data));
        if((this.cart_data!=null && this.cart_data!='') &&(!this.insert_code)) {
            let cart_data = [];
            this.cart_data.cart_details.forEach((a,i)=>{
                let push_data = {
                    item_name       : a.product.name,
                    item_id         : a.product.id,
                    price           : a.product_price,
                    quantity        : a.qty,
                    variant_id      : a.selected_price_type,
                    item_category   : (a.product.default_category!=null) ? a.product.default_category.name : ""
                };
                cart_data.push(push_data);
            });
            productSelection(cart_data,'begin_checkout_stage_2');
            this.insert_code = true;
        }
        setInterval(() => {
            this.checkCartData();
        }, 300000);
    },
    methods : {
        checkCartData() {
            if(this.cart_data.completed_type==0){
                let final_data = JSON.stringify(cloneDeep(this.cart_data));
                if(this.initial_data!=final_data) {
                    let cart_id  = this.cart_data.id;
                    let domain_id = this.$store.state.front_end_data.domain_id;
                    let location  = (this.$auth.$storage.getUniversal('location')!=undefined) ? this.$auth.$storage.getUniversal('location') : null;
                    this.cart_data.tag_name="stage_2";
                    let final_post_data = cloneDeep(this.cart_data);
                    if(this.cart_data.dob!=null) {
                        final_post_data.dob = moment(this.cart_data.dob,'DD/MM/YYYY').format('YYYY-MM-DD');
                    }
                    this.$axios.$post(`/api/store-automatic-orders/${cart_id}/${location}/${domain_id}`,final_post_data)
                    .then(resp=>{
                        if(resp.dob!=null) {
                            resp.dob = moment(resp.dob).format('DD/MM/YYYY');
                        }
                        this.cart_data = resp;
                        final_data = JSON.stringify(cloneDeep(this.cart_data));
                        this.initial_data = final_data;
                    })
                }
            }
        }
    }
}
</script>